summaryrefslogtreecommitdiffstats
path: root/install/ui/dns.js
diff options
context:
space:
mode:
authorMartin Kosek <mkosek@redhat.com>2011-04-01 17:09:07 +0200
committerEndi Sukma Dewata <edewata@people01.fedoraproject.org>2011-04-21 19:03:38 +0000
commitbc6f9accd9250114b4f0c457fa5badd7f794af8e (patch)
treef18dd93a8f0fd53ef86c5eefde428a96c796c462 /install/ui/dns.js
parentd9c17612341af82405873dde120b177dbc0abd83 (diff)
downloadfreeipa-bc6f9accd9250114b4f0c457fa5badd7f794af8e.tar.gz
freeipa-bc6f9accd9250114b4f0c457fa5badd7f794af8e.tar.xz
freeipa-bc6f9accd9250114b4f0c457fa5badd7f794af8e.zip
Need force option in DNS zone adder dialog
When adding a new DNS zone in the WebUI, IPA server will verify whether the nameserver is in DNS. Sometimes it is necessary to skip the verification. This patch adds a --force option already available in CLI which can skip this the verification. https://fedorahosted.org/freeipa/ticket/1105
Diffstat (limited to 'install/ui/dns.js')
-rw-r--r--install/ui/dns.js12
1 files changed, 10 insertions, 2 deletions
diff --git a/install/ui/dns.js b/install/ui/dns.js
index 08aac113c..d89982803 100644
--- a/install/ui/dns.js
+++ b/install/ui/dns.js
@@ -21,7 +21,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
/* REQUIRES: ipa.js, details.js, search.js, add.js, entity.js */
/* DNS */
IPA.entity_factories.dnszone = function() {
@@ -30,7 +30,7 @@ IPA.entity_factories.dnszone = function() {
entity('dnszone').
search_facet({
columns:['idnsname'],
- add_fields: ['idnsname','idnssoamname','idnssoarname']
+ add_fields: ['idnsname','idnssoamname','idnssoarname', {factory:IPA.force_dnszone_add_checkbox_widget}]
}).
details_facet({sections:[{
name:'identity',
@@ -57,6 +57,14 @@ IPA.entity_factories.dnszone = function() {
build();
};
+IPA.force_dnszone_add_checkbox_widget = function (spec){
+ var param_info = IPA.get_method_param('dnszone_add', 'force');
+ spec.name = 'force';
+ spec.label = param_info.label;
+ spec.tooltip = param_info.doc;
+ spec.undo = false;
+ return IPA.checkbox_widget(spec);
+};
IPA.records_facet = function (spec){
@@ -21,7 +21,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-/* REQUIRES: ipa.js, details.js, search.js, add.js, entity.js */
+/* REQUIRES: ipa.js, details.js, search.js, add.js, entity.js, widget.js */
/* DNS */
IPA.entity_factories.dnszone = function() {